#!/usr/bin/env bash

FABRIC_TASKS="$( fab --shortlist )"


fabric_task_exists() {
    if [ ! -e 'fabfile.py' ]
    then
        b5_abort "No fabfile.py found"
    fi

    if [ $( echo "${FABRIC_TASKS}" | grep "$1" | wc -l ) -gt 0 ]
    then
        return 0
    else
        return 1
    fi
}

# COMMON TASKS

if fabric_task_exists 'setup'
then
    task:install() {
        fab setup
    }
fi

if fabric_task_exists 'install'
then
    task:update() {
        fab install
    }
fi

if fabric_task_exists 'css'
then
    task:css() {
        fab css
    }
fi

if fabric_task_exists 'watch'
then
    task:watch() {
        fab watch
    }
fi

if fabric_task_exists 'deploy'
then
    task:deploy() {
        if [ -z "$1" ]
        then
            echo "No target given, aborting"
            exit 1
        fi
        fab $1 deploy:$2
    }
fi

if fabric_task_exists 'deploy_setup'
then
    task:deploy_setup() {
        if [ -z "$1" ]
        then
            echo "No target given, aborting"
            exit 1
        fi
        fab $1 deploy_setup
    }
fi

# MORE TASKS FOUND IN PROJECTS

if fabric_task_exists 'compilemessages'
then
    task:compilemessages() {
        fab compilemessages
    }
fi

if fabric_task_exists 'makemessages'
then
    task:makemessages() {
        fab makemessages
    }
fi

if fabric_task_exists 'deploy_apply_files'
then
    task:deploy_apply_files() {
        fab deploy_apply_files
    }
fi

if fabric_task_exists 'deploy_files'
then
    task:deploy_files() {
        fab deploy_files
    }
fi

if fabric_task_exists 'deploy_migrate'
then
    task:deploy_migrate() {
        fab deploy_migrate
    }
fi

if fabric_task_exists 'deploy_push_files'
then
    task:deploy_push_files() {
        fab deploy_push_files
    }
fi

if fabric_task_exists 'deploy_restart'
then
    task:deploy_restart() {
        fab deploy_restart
    }
fi

if fabric_task_exists 'deploy_start'
then
    task:deploy_start() {
        fab deploy_start
    }
fi

if fabric_task_exists 'deploy_static'
then
    task:deploy_static() {
        fab deploy_static
    }
fi

if fabric_task_exists 'deploy_stop'
then
    task:deploy_stop() {
        fab deploy_stop
    }
fi

if fabric_task_exists 'migrate'
then
    task:migrate() {
        fab migrate
    }
fi

if fabric_task_exists 'run'
then
    task:run() {
        fab run
    }
fi


if fabric_task_exists 'rundev'
then
    task:rundev() {
        fab rundev
    }
fi


if fabric_task_exists 'shell'
then
    task:shell() {
        fab shell
    }
fi


if fabric_task_exists 'static'
then
    task:static() {
        fab static
    }
fi


if fabric_task_exists 'syncdb'
then
    task:syncdb() {
        fab syncdb
    }
fi

if fabric_task_exists 'browsersync'
then
    task:browsersync() {
        fab browsersync:"$1"
    }
fi

if fabric_task_exists 'icons'
then
    task:icons() {
        fab icons
    }
fi

if fabric_task_exists 'deploy_clear_cache'
then
    task:deploy_clear_cache() {
        fab deploy_clear_cache
    }
fi

if fabric_task_exists 'deploy_database_compare'
then
    task:deploy_database_compare() {
        fab deploy_database_compare
    }
fi

if fabric_task_exists 'deploy_enable_install_tool'
then
    task:deploy_enable_install_tool() {
        fab deploy_enable_install_tool
    }
fi

if fabric_task_exists 'deploy_disable_install_tool'
then
    task:deploy_disable_install_tool() {
        fab deploy_disable_install_tool
    }
fi

if fabric_task_exists 'deploy_maintenance_enable'
then
    task:deploy_maintenance_enable() {
        fab deploy_maintenance_enable
    }
fi

if fabric_task_exists 'deploy_maintenance_disable'
then
    task:deploy_maintenance_disable() {
        fab deploy_maintenance_disable
    }
fi

if fabric_task_exists 'deploy_cc'
then
    task:deploy_cc() {
        fab deploy_cc
    }
fi

if fabric_task_exists 'deploy_drush'
then
    task:deploy_drush() {
        fab deploy_drush:"$1"
    }
fi

